@@ -11,12 +11,12 @@ from urllib.parse import urljoin
 from appknox.exceptions import (
     OneTimePasswordError, CredentialError, AppknoxError,
     OrganizationError, UploadError, SubmissionNotFound,
-    SubmissionError, SubmissionFileTimeoutError, RescanError
+    SubmissionError, SubmissionFileTimeoutError, RescanError, ProfileReportPreferenceError
 )
 from appknox.mapper import (
     mapper_json_api, mapper_drf_api, Analysis, File, Project, User,
     Organization, Vulnerability, OWASP, PCIDSS, PersonalToken, Submission,
-    Whoami
+    Whoami, ProfileReportPreference, ReportPreferenceMapper
 )
 
 DEFAULT_API_HOST = 'https://api.appknox.com'
@@ -511,6 +511,31 @@ class Appknox(object):
             raise RescanError('Something went wrong, retry rescan')
         return file
 
+    def get_profile_report_preference(self, profile_id: int) -> ProfileReportPreference:
+        """
+        Fetch profile report preference
+        """
+        try:
+            profile_report_preference = self.drf_api['profiles/{}/report_preference'.format(profile_id)]().get()
+        except:
+            raise ProfileReportPreferenceError('Could not fetch profile report preference')
+        return ProfileReportPreference.from_json(profile_report_preference)
+
+    def get_unselected_report_preference(self, file_id: int) -> list:
+        """
+        Get a list of unselected report preference items
+        """
+        file = self.get_file(file_id)
+        profile_report_preference = self.get_profile_report_preference(file.profile)
+        unselected_report_pref = list()
+        if (not profile_report_preference.show_gdpr.value):
+            unselected_report_pref.append(ReportPreferenceMapper['show_gdpr'])
+        if (not profile_report_preference.show_hipaa.value):
+            unselected_report_pref.append(ReportPreferenceMapper['show_hipaa'])
+        if (not profile_report_preference.show_pcidss.value):
+            unselected_report_pref.append(ReportPreferenceMapper['show_pcidss'])
+        return unselected_report_pref
+
     # def get_report(
     #         self, file_id, format: str = 'json', language: str = 'en') ->
     #         str:
