@@ -1,7 +1,7 @@
 # (c) 2017, XYSec Labs
 
 from collections import namedtuple
-
+from dataclasses import dataclass
 
 def mapper_json_api(model: type, resource: dict) -> object:
     """
@@ -48,7 +48,7 @@ Project = namedtuple(
 
 File = namedtuple(
     'File',
-    ['id', 'name', 'version', 'version_code', 'static_scan_progress']
+    ['id', 'name', 'version', 'version_code', 'static_scan_progress', 'profile']
 )
 
 Submission = namedtuple(
@@ -60,7 +60,7 @@ Analysis = namedtuple(
     'Analysis',
     ['id', 'risk', 'status', 'cvss_base', 'cvss_vector', 'cvss_version',
      'cvss_metrics_humanized', 'findings', 'updated_on', 'vulnerability',
-     'owasp', 'pcidss', 'hipaa']
+     'owasp', 'pcidss', 'hipaa', 'cwe', 'mstg', 'asvs', 'gdpr', 'computed_risk', 'overridden_risk']
 )
 
 Vulnerability = namedtuple(
@@ -83,3 +83,26 @@ PersonalToken = namedtuple(
     'AccessToken',
     ['name', 'key']
 )
+
+ReportPreferenceMapper = {
+    'show_pcidss': 'pcidss',
+    'show_hipaa': 'hipaa',
+    'show_gdpr': 'gdpr'}
+
+@dataclass
+class ProfileReportPreferenceConfig:
+    value: bool
+
+@dataclass
+class ProfileReportPreference:
+    show_gdpr: ProfileReportPreferenceConfig
+    show_hipaa: ProfileReportPreferenceConfig
+    show_pcidss: ProfileReportPreferenceConfig
+
+    @classmethod
+    def from_json(cls, data):
+        return cls(
+            show_gdpr=ProfileReportPreferenceConfig(value=data['show_gdpr']['value']),
+            show_hipaa=ProfileReportPreferenceConfig(value=data['show_hipaa']['value']),
+            show_pcidss=ProfileReportPreferenceConfig(value=data['show_pcidss']['value'])
+        )
